@@ -69,16 +69,17 @@ class Arena():
         if name in ['username', '_username', 'password', '_password']:
             raise AttributeError
 
-        try:
-            obj= getattr(classes, name)
+        obj = getattr(classes, name, None)
 
-            if not isinstance(obj, type):
-                raise(KeyError)
-        except:
-            try:
-                return self.__dict__[name]
-            except KeyError:
-                raise AttributeError
+        if not obj and name in self.__dict__:
+            return self.__dict__[name]
+        elif not obj:
+            raise AttributeError
+
+        if obj and not isinstance(obj, type):
+            raise AttributeError
+        elif not obj:
+            raise AttributeError
 
         obj._client=self
 
@@ -206,6 +207,8 @@ class Arena():
         - limit     - The maximum number to fetch. Defaults to 400, the maximum number of objects that may be returned by one Arena API call.
         - offset    - Offset for result returns. Defaults to 0 (no offset). Mainly used in recursive pagination calls.
         - **kwargs  - Property arguments for search parameters.
+
+        Returns: List of objects
         '''
 
         if isinstance(obj, str):
@@ -264,6 +267,8 @@ class Arena():
         - limit     - The maximum number to fetch. Defaults to 400, the maximum number of objects that may be returned by one Arena API call.
         - offset    - Offset for result returns. Defaults to 0 (no offset). Mainly used in recursive pagination calls.
         - delay     - Time to sleep (in seconds) between API calls.
+
+        Yields objects
         """
 
         initial = self.Listing(obj, endpoint, limit, offset, **kwargs)
